@@ -1,9 +1,11 @@
+from math import floor
+
 
 class ABC:
     def asciify_pixel(self, p):  # takes [b, g, r]
         # assumes that there is a self.gradient, and a self.gradient_len
         # gradient calculation
-        return self.gradient[int((((int(p[0]) + int(p[1]) + int(p[2])) / 3)*(self.gradient_len))/255)]
+        return self.gradient[floor((((int(p[0]) + int(p[1]) + int(p[2])) / 3)*(self.gradient_len))/255)]
         # standard luminosity calculation
         # return self.gradient[int(((.2126*p[2] + .587*p[1] + .114*p[0])/255)*self.gradient_len)]
 
